@@ -4,12 +4,12 @@ mapdeckScatterplotDependency <- function() {
 			name = "scatterplot",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/scatterplot", package = "mapdeck"),
-			script = c("scatterplot.js")
+			script = c("scatterplot.js"),
+			all_files = FALSE
 		)
 	)
 }
 
-
 #' Add Scatterplot
 #'
 #' The Scatterplot Layer takes in coordinate points and renders them as circles
@@ -18,10 +18,12 @@ mapdeckScatterplotDependency <- function() {
 #' @inheritParams add_polygon
 #' @param lon column containing longitude values
 #' @param lat column containing latitude values
-#' @param radius in metres
-#' @param palette string or matrix. String will be one of \code{colourvalues::colour_palettes()}.
-#' A matrix is a 3 or 4 column numeric matrix of values between [0, 255],
-#' where the 4th column represents the alpha.
+#' @param radius in metres. Default 1
+#' @param radius_min_pixels the minimum radius in pixels. Can prevent circle from
+#' getting too small when zoomed out
+#' small for the given zoom level
+#' @param radius_max_pixels the maximum radius in pixels. Can prevent the circle from
+#' getting too big when zoomed in
 #'
 #' @inheritSection add_polygon data
 #' @inheritSection add_arc legend
@@ -48,8 +50,9 @@ mapdeckScatterplotDependency <- function() {
 #' \donttest{
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
-#' mapdeck( token = key, style = mapdeck_style("dark"), pitch = 45 ) %>%
+#' mapdeck( style = mapdeck_style("dark"), pitch = 45 ) %>%
 #' add_scatterplot(
 #'   data = capitals
 #'   , lat = "lat"
@@ -60,6 +63,22 @@ mapdeckScatterplotDependency <- function() {
 #'   , tooltip = "capital"
 #' )
 #'
+#' ## using legend options
+#' mapdeck( style = mapdeck_style("dark"), pitch = 45 ) %>%
+#' add_scatterplot(
+#'   data = capitals
+#'   , lat = "lat"
+#'   , lon = "lon"
+#'   , radius = 100000
+#'   , fill_colour = "lon"
+#'   , stroke_colour = "lat"
+#'   , layer_id = "scatter_layer"
+#'   , tooltip = "capital"
+#'   , legend = T
+#'   , legend_options = list( digits = 5 )
+#' )
+#'
+#'
 #' df <- read.csv(paste0(
 #' 'https://raw.githubusercontent.com/uber-common/deck.gl-data/master/',
 #' 'examples/3d-heatmap/heatmap-data.csv'
@@ -67,22 +86,23 @@ mapdeckScatterplotDependency <- function() {
 #'
 #' df <- df[ !is.na(df$lng), ]
 #'
-#' mapdeck( token = key, style = mapdeck_style("dark"), pitch = 45 ) %>%
+#' mapdeck(style = mapdeck_style("dark"), pitch = 45 ) %>%
 #' add_scatterplot(
 #'   data = df
 #'   , lat = "lat"
 #'   , lon = "lng"
 #'   , layer_id = "scatter_layer"
+#'   , stroke_colour = "lng"
 #' )
 #'
 #' ## as an sf object
-#' library(sf)
-#' sf <- sf::st_as_sf( capitals, coords = c("lon", "lat") )
+#' library(sfheaders)
+#' sf <- sfheaders::sf_point( df, x = "lng", y = "lat")
 #'
-#' mapdeck( token = key, style = mapdeck_style("dark"), pitch = 45 ) %>%
+#' mapdeck( style = mapdeck_style("dark"), pitch = 45 ) %>%
 #' add_scatterplot(
 #'   data = sf
-#'   , radius = 100000
+#'   , radius = 100
 #'   , fill_colour = "country"
 #'   , layer_id = "scatter_layer"
 #'   , tooltip = "capital"
@@ -102,8 +122,13 @@ add_scatterplot <- function(
 	lat = NULL,
 	polyline = NULL,
 	radius = NULL,
+	radius_min_pixels = 1,
+	radius_max_pixels = NULL,
 	fill_colour = NULL,
 	fill_opacity = NULL,
+	stroke_colour = NULL,
+	stroke_width = NULL,
+	stroke_opacity = NULL,
 	tooltip = NULL,
 	auto_highlight = FALSE,
 	highlight_colour = "#AAFFFFFF",
@@ -114,18 +139,31 @@ add_scatterplot <- function(
 	legend = FALSE,
 	legend_options = NULL,
 	legend_format = NULL,
+	digits = 6,
 	update_view = TRUE,
 	focus_layer = FALSE,
-	transitions = NULL
+	transitions = NULL,
+	brush_radius = NULL
 ) {
 
+	## using binary data requires hex-colorus to include teh alpha
+	if( !is.null( fill_colour ) ) {
+		fill_colour <- appendAlpha( fill_colour )
+	}
+	if( !is.null( stroke_colour ) ) {
+		stroke_colour <- appendAlpha( stroke_colour )
+	}
+
 	l <- list()
 	l[["lon"]] <- force(lon)
 	l[["lat"]] <- force(lat)
 	l[["polyline"]] <- force(polyline)
 	l[["radius"]] <- force(radius)
 	l[["fill_colour"]] <- force(fill_colour)
-	l[["fill_opacity"]] <- force(fill_opacity)
+	l[["fill_opacity"]] <- resolve_opacity(fill_opacity)
+	l[["stroke_colour"]] <- force( stroke_colour)
+	l[["stroke_opacity"]] <- force( stroke_opacity )
+	l[["stroke_width"]] <- force( stroke_width )
 	l[["tooltip"]] <- force(tooltip)
 	l[["id"]] <- force(id)
 	l[["na_colour"]] <- force(na_colour)
@@ -133,7 +171,7 @@ add_scatterplot <- function(
 	l <- resolve_palette( l, palette )
 	l <- resolve_legend( l, legend )
 	l <- resolve_legend_options( l, legend_options )
-	l <- resolve_data( data, l, c( "POINT", "MULTIPOINT") )
+	l <- resolve_data( data, l, c( "POINT") )
 
 	bbox <- init_bbox()
 	update_view <- force( update_view )
@@ -154,54 +192,48 @@ add_scatterplot <- function(
 
 	map <- addDependency(map, mapdeckScatterplotDependency())
 
-
 	tp <- l[["data_type"]]
 	l[["data_type"]] <- NULL
 
-	jsfunc <- "add_scatterplot_geo"
+	jsfunc <- "add_scatterplot_geo_columnar"
+	map <- addDependency(map, mapdeckScatterplotDependency())
+
 	if ( tp == "sf" ) {
-		geometry_column <- c( "geometry" )
-		shape <- rcpp_scatterplot_geojson( data, l, geometry_column )
+		geometry_column <- list( geometry = c("lon","lat") )  ## using columnar structure, the 'sf' is converted to a data.frame
+		## so the geometry columns are obtained after sfheaders::sf_to_df()
+		l[["geometry"]] <- NULL
+		shape <- rcpp_point_sf_columnar( data, l, geometry_column, digits, "scatterplot" )
+
 	} else if ( tp == "df" ) {
-		geometry_column <- list( geometry = c("lon", "lat") )
-		shape <- rcpp_scatterplot_geojson_df( data, l, geometry_column )
+
+	  geometry_column <- list( geometry = c("lon", "lat") )
+	  shape <- rcpp_point_df_columnar( data, l, geometry_column, digits, "scatterplot" )
+
 	} else if ( tp == "sfencoded" ) {
+
 		geometry_column <- c( "polyline" )
-		shape <- rcpp_scatterplot_polyline( data, l, geometry_column )
-		jsfunc <- "add_scatterplot_polyline"
+		shape <- rcpp_point_polyline( data, l, geometry_column, "scatterplot" )
 	}
 
 	js_transitions <- resolve_transitions( transitions, "scatterplot" )
-	shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+
+
+	if( inherits( legend, "json" ) ) {
+		shape[["legend"]] <- legend
+	} else {
+		shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], layer_id, auto_highlight, highlight_colour,
-		shape[["legend"]], bbox, update_view, focus_layer, js_transitions
+		map, jsfunc, map_type( map ), shape[["data"]], nrow(data) , layer_id, auto_highlight, highlight_colour,
+		shape[["legend"]], bbox, update_view, focus_layer, js_transitions,
+		radius_min_pixels, radius_max_pixels, brush_radius
 		)
 }
 
-resolve_args <- function( l, layer_args ) {
-
-	## This implementation will allow variables passed in as column names
-	## but NOT un-quoted column variables
-	x <- vapply(names(l), function(x) { x %in% layer_args }, T)
-	x <- x[x]    ## x is the set of arguments we need to evaluate
-	l <- l[names(x)]
-	lapply( l, eval )
-}
-
-
-## args used which can be columns of 'data'
-scatterplot_data_args <- function() {
-	return(
-		c("lon", "lat", "polyline", "radius", "fill_colour", "fill_opacity", "tooltip")
-	)
-}
-
-
 #' @rdname clear
 #' @export
 clear_scatterplot <- function( map, layer_id = NULL) {
 	layer_id <- layerId(layer_id, "scatterplot")
-	invoke_method(map, "md_layer_clear", layer_id, "scatterplot" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "scatterplot" )
 }
