@@ -4,7 +4,8 @@ mapdeckTextDependency <- function() {
 			name = "text",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/text", package = "mapdeck"),
-			script = c("text.js")
+			script = c("text.js"),
+			all_files = FALSE
 		)
 	)
 }
@@ -16,12 +17,19 @@ mapdeckTextDependency <- function() {
 #'
 #' @inheritParams add_scatterplot
 #' @param text column of \code{data} containing the text. The data must be a character.
-#' @param size column of \code{data} containing the size of the text
-#' @param angle column of \code{data} containging the angle of the text
+#' @param size column of \code{data} containing the size of the text. Default 32
+#' @param angle column of \code{data} containging the angle of the text. Default 0
 #' @param anchor column of \code{data} containing the anchor of the text. One of
 #' 'start', 'middle' or 'end'
 #' @param alignment_baseline column of \code{data} containing the alignment. One of
 #' 'top', 'center' or 'bottom'
+#' @param billboard logical indicating if the text always faces the camera (TRUE) or
+#' if it always faces up (FALSE)
+#' @param font_family specifies a prioritised list of one or more font family names and/or
+#' generic family names. Follow the specifics for CSS font-family
+#' \url{https://developer.mozilla.org/en-US/docs/Web/CSS/font-family}
+#' @param font_weight specifies the font weight. Follow the specifics for CSS font-weight
+#' \url{https://htmldog.com/references/css/properties/font-weight/}
 #' @param tooltip variable of \code{data} containing text or HTML to render as a tooltip
 #'
 #' @inheritSection add_arc legend
@@ -50,9 +58,9 @@ mapdeckTextDependency <- function() {
 #'
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
 #' mapdeck(
-#'   token = key,
 #'   style = mapdeck_style('dark')
 #' ) %>%
 #'   add_text(
@@ -83,6 +91,9 @@ add_text <- function(
 	angle = NULL,
 	anchor = NULL,
 	alignment_baseline = NULL,
+	billboard = TRUE,
+	font_family = 'Monaco, monospace',
+	font_weight = "normal",
 	tooltip = NULL,
 	layer_id = NULL,
 	id = NULL,
@@ -92,16 +103,19 @@ add_text <- function(
 	na_colour = "#808080FF",
 	legend = FALSE,
 	legend_options = NULL,
+	legend_format = NULL,
 	update_view = TRUE,
 	focus_layer = FALSE,
-	transitions = NULL
+	digits = 6,
+	transitions = NULL,
+	brush_radius = NULL
 ) {
 
 	l <- list()
 	l[["lon"]] <- force( lon )
 	l[["lat"]] <- force( lat )
 	l[["fill_colour"]] <- force( fill_colour )
-	l[["fill_opacity"]] <- force( fill_opacity )
+	l[["fill_opacity"]] <- resolve_opacity( fill_opacity )
 	l[["size"]] <- force( size )
 	l[["text"]] <- force( text )
 	l[["polyline"]] <- force( polyline )
@@ -115,7 +129,7 @@ add_text <- function(
 	l <- resolve_palette( l, palette )
 	l <- resolve_legend( l, legend )
 	l <- resolve_legend_options( l, legend_options )
-	l <- resolve_data( data, l, c("POINT","MULTIPOINT"))
+	l <- resolve_data( data, l, c("POINT"))
 
 	bbox <- init_bbox()
 	update_view <- force( update_view )
@@ -146,10 +160,10 @@ add_text <- function(
 
 	if( tp == "sf" ) {
 		geometry_column <- c( "geometry" )
-		shape <- rcpp_text_geojson( data, l, geometry_column )
+		shape <- rcpp_text_geojson( data, l, geometry_column, digits )
 	} else if ( tp == "df" ) {
 		geometry_column <- list( geometry = c("lon", "lat") )
-		shape <- rcpp_text_geojson_df( data, l, geometry_column )
+		shape <- rcpp_text_geojson_df( data, l, geometry_column, digits )
 	} else if ( tp == "sfencoded" ) {
 		geometry_column <- "polyline"
 		shape <- rcpp_text_polyline( data, l, geometry_column )
@@ -157,10 +171,16 @@ add_text <- function(
 	}
 
 	js_transitions <- resolve_transitions( transitions, "text" )
+	if( inherits( legend, "json" ) ) {
+		shape[["legend"]] <- legend
+	} else {
+		shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], layer_id, auto_highlight, highlight_colour,
-		shape[["legend"]], bbox, update_view, focus_layer, js_transitions
+		map, jsfunc, map_type( map ), shape[["data"]], layer_id, auto_highlight, highlight_colour,
+		shape[["legend"]], bbox, update_view, focus_layer, js_transitions, billboard,
+		font_family, font_weight, brush_radius
 		)
 }
 
@@ -168,6 +188,6 @@ add_text <- function(
 #' @export
 clear_text <- function( map, layer_id = NULL) {
 	layer_id <- layerId(layer_id, "text")
-	invoke_method(map, "md_layer_clear", layer_id, "text" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "text" )
 }
 
